@@ -2,7 +2,7 @@
 
 
 #' @importFrom   stats rnorm
-cooccur.readfasta.read <- function(dataFile="", parallel=FALSE, cpus=cooccur.detectCores(), debug=FALSE){
+cooccur.readfasta.read <- function(dataFile="",  debug=FALSE){
   #require(seqinr)
   #require(data.table)
   #require(snowfall)
@@ -19,13 +19,12 @@ cooccur.readfasta.read <- function(dataFile="", parallel=FALSE, cpus=cooccur.det
 		#stop("Package 'snowfall' is required.")
 	#}
 
-
-	seqlevel = c("A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","-","0","1","2","3","4","5","6","7","8","9")
+  seqlevel = c()
+	#seqlevel = c("A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","-","0","1","2","3","4","5","6","7","8","9")
 	seqidlevel = c(2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71,73, 79, 83, 89, 97, 101, 103, 107, 109, 113,127,131,137,139,149,151,157,163,173,179,181,191,193  )
 	cooccur.preprocess.object = list(matrix=NA, freqMatrix=NA, dt_idxtable=NA, bigramFreqList=NA, memory=NA, conn=NA, seqlevel=NA, seqidlevel=NA)
 
-	cooccur.preprocess.object$seqlevel = seqlevel
-	cooccur.preprocess.object$seqidlevel = seqidlevel
+
 
 	sequences = c()
 
@@ -50,11 +49,16 @@ cooccur.readfasta.read <- function(dataFile="", parallel=FALSE, cpus=cooccur.det
 
 	xnames = sequences[ind]
 
+
 	#2016-09-14 modified begin
 	xnames = substr(xnames, 2, nchar(xnames))
+
 	xx = substr(xnames, (regexpr("\\|", xnames) + 1), nchar(xnames))
-	xnames = substr(xx,1, (ifelse(regexpr("\\|", xx)==-1,nchar(xx),regexpr("\\|", xx)) - 1))
+
+	xnames = substr(xx,1, (ifelse(regexpr("\\|", xx)==-1,nchar(xx),regexpr("\\|", xx)-1)))
 	#2016-09-14 modified end
+
+	#print(xnames)
 	cooccur.preprocess.object$xnames = xnames
 
 	nseq <- length(ind)
@@ -73,6 +77,19 @@ cooccur.readfasta.read <- function(dataFile="", parallel=FALSE, cpus=cooccur.det
 	t = Sys.time()
 
 	sequences <- lapply(seq_len(nseq), function(i) paste(sequences[start[i]:end[i]], collapse = ""))
+  #print(sequences)
+
+
+  seqlevel <- lapply(sequences, function(x){
+    x = seqinr::s2c(x)
+    names(table(x))
+  })
+  seqlevel = names(table(do.call(c, seqlevel)))
+  #print(seqlevel)
+
+  if(debug){
+    message(paste("character level:", paste(seqlevel, collapse = ","), sep=""))
+  }
 
 	sequences_original <- sequences
 	sequences <- lapply(sequences, function(x){
@@ -92,22 +109,25 @@ cooccur.readfasta.read <- function(dataFile="", parallel=FALSE, cpus=cooccur.det
 
 
 	cooccur.preprocess.object$original = sequences_original
-	cooccur.preprocess.object$original_ncol = ncol(sequences_original)
+	#cooccur.preprocess.object$original_ncol = ncol(sequences_original)
 
 	cooccur.preprocess.object$matrix = sequences
 	storage.mode(cooccur.preprocess.object$matrix) <- "integer"
 
-	constantList <- cooccur.constant()
+	#constantList <- cooccur.constant()
+	constantList <- cooccur.constant.new(seqlevel)
 	cooccur.preprocess.object$constantList = constantList
 
-	dt_idxtable_filename = paste("dt_idxtable_",rnorm(1)*100000000,sep="")
+	#dt_idxtable_filename = paste("dt_idxtable_",rnorm(1)*100000000,sep="")
 	#print(dt_idxtable_filename)
-	cooccur.preprocess.object$dt_idxtable_filename = dt_idxtable_filename
+	#cooccur.preprocess.object$dt_idxtable_filename = dt_idxtable_filename
 	cooccur.printTimeCost('split string to character time cost',t, debug)
 
 	#print(dim(cooccur.preprocess.object$matrix))
 	#print(dim(cooccur.preprocess.object$original))
 
+	cooccur.preprocess.object$seqlevel = seqlevel
+	cooccur.preprocess.object$seqidlevel = seqidlevel
 
 	return(cooccur.preprocess.object)
 }
